<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'yes' => 'Ναι',
    'no' => 'Όχι',
    'update' => 'Ενημέρωση',
    'save' => 'Αποθήκευση',
    'add' => 'Προσθήκη',
    'cancel' => 'Ακύρωση',
    'confirm' => 'Επιβεβαίωση',
    'delete_confirm' => 'Είστε σίγουροι;',
    'delete' => 'Διαγραφή',
    'edit' => 'Επεξεργασία',
    'upload' => 'Μεταφόρτωση',
    'download' => 'Λήψη',
    'save_close' => 'Αποθήκευση και κλείσιμο',
    'close' => 'Κλείσιμο',
    'copy' => 'Αντιγραφή',
    'create' => 'Δημιουργία',
    'remove' => 'Κατάργηση',
    'revoke' => 'Ανάκληση',
    'done' => 'Ολοκληρώθηκε',
    'back' => 'Πίσω',
    'verify' => 'Επαλήθευση',
    'new' => 'νέο',
    'unknown' => 'Δεν γνωρίζω',
    'load_more' => 'Εμφάνιση περισσότερων',
    'loading' => 'Φόρτωση…',
    'with' => 'με',
    'today' => 'σήμερα',
    'yesterday' => 'χθες',
    'another_day' => 'άλλη μέρα',
    'date' => 'Ημερομηνία',
    'type' => 'Τύπος',
    'zoom' => 'Μεγέθυνση',
    'upgrade' => 'Αναβαθμίστε για να ξεκλειδώσετε',
    'percent_uploaded' => '{percent}% έχει μεταφορτωθεί',
    'retry' => 'Ξαναδοκιμάστε',
    'filter' => 'Φιλτράρισμα λίστας',
    'go_back' => 'Επιστροφή',
    'file_selected' => 'Επιλέχθηκε ένα αρχείο…|{count} επιλεγμένα αρχεία…',

    'application_title' => 'Monica – διαχειριστής προσωπικών σχέσεων',
    'application_description' => 'Το Monica είναι ένα εργαλείο που διαχειρίζεται τις επαφές σας με τους αγαπημένους σας, τους φίλους και την οικογένεια.',
    'application_og_title' => 'Βελτιώστε τις σχέσεις με του αγαπημένους σας. Δωρεάν Online CRM για φίλους και οικογένεια.',

    'markdown_description' => 'Θέλετε να μορφοποιήσετε το κείμενο σας όμορφα; Υποστηρίζουμε Markdown για να προσθέσετε εντονη, πλάγια γραφή, λίστες και περισσότερα.',
    'markdown_link' => 'Διαβάστε την τεκμηρίωση',

    'header_settings_link' => 'Ρυθμίσεις',
    'header_logout_link' => 'Αποσύνδεση',
    'header_changelog_link' => 'Αλλαγές προϊόντος',

    'main_nav_cta' => 'Προσθήκη ατόμων',
    'main_nav_dashboard' => 'Επισκόπηση',
    'main_nav_family' => 'Επαφές',
    'main_nav_journal' => 'Προσωπικό Ημερολόγιο',
    'main_nav_activities' => 'Δραστηριότητες',
    'main_nav_tasks' => 'Εργασίες',

    'footer_remarks' => 'Σχόλια;',
    'footer_send_email' => 'Στείλτε μας ένα email',
    'footer_privacy' => 'Πολιτική απορρήτου',
    'footer_release' => 'Σημειώσεις έκδοσης',
    'footer_newsletter' => 'Newsletter',
    'footer_source_code' => 'Συμβάλλετε',
    'footer_version' => 'Έκδοση :version',
    'footer_new_version' => 'Μια νέα έκδοση της εφαρμογής Monica είναι διαθέσιμη',

    'footer_modal_version_whats_new' => 'Τι νέο υπάρχει;',
    'footer_modal_version_release_away' => 'Είστε 1 έκδοση πίσω από την τελευταία διαθέσιμη έκδοση. Θα πρέπει να αναβαθμίσετε την εγκατάσταση σας.|Είστε :number εκδόσεις πίσω από την τελευταία διαθέσιμη έκδοση. Θα πρέπει να αναβαθμίσετε την εγκατάσταση σας.',

    'breadcrumb_dashboard' => 'Επισκόπηση',
    'breadcrumb_list_contacts' => 'Λίστα επαφών',
    'breadcrumb_archived_contacts' => 'Αρχειοθετημένες επαφές',
    'breadcrumb_journal' => 'Προσωπικό Ημερολόγιο',
    'breadcrumb_settings' => 'Ρυθμίσεις',
    'breadcrumb_settings_export' => 'Εξαγωγή',
    'breadcrumb_settings_users' => 'Χρήστες',
    'breadcrumb_settings_users_add' => 'Προσθήκη χρήστη',
    'breadcrumb_settings_subscriptions' => 'Συνδρομή',
    'breadcrumb_settings_import' => 'Εισαγωγή',
    'breadcrumb_settings_import_report' => 'Αναφορά εισαγωγής',
    'breadcrumb_settings_import_upload' => 'Μεταφόρτωση',
    'breadcrumb_settings_tags' => 'Ετικέτες',
    'breadcrumb_add_significant_other' => 'Προσθήκη συντρόφου',
    'breadcrumb_edit_significant_other' => 'Επεξεργασία συντρόφου',
    'breadcrumb_add_note' => 'Προσθήκη σημείωσης',
    'breadcrumb_edit_note' => 'Επεξεργασία σημείωσης',
    'breadcrumb_api' => 'API',
    'breadcrumb_dav' => 'Πόροι DAV',
    'breadcrumb_edit_introductions' => 'Πώς γνωριστήκατε;',
    'breadcrumb_settings_personalization' => 'Εξατομίκευση',
    'breadcrumb_settings_security' => 'Ασφάλεια',
    'breadcrumb_settings_security_2fa' => 'Έλεγχος Ταυτότητας Δυο Παραγόντων',
    'breadcrumb_profile' => 'Προφίλ του :name',

    'gender_male' => 'Άντρας',
    'gender_female' => 'Γυναίκα',
    'gender_none' => 'Χωρίς δήλωση',
    'gender_no_gender' => 'Χωρίς φύλο',

    'error_title' => 'Ωχ... κάτι πήγε στραβά.',
    'error_unauthorized' => 'Δεν έχετε δικαίωμα να επεξεργαστείτε αυτή τη σελίδα.',
    'error_user_account' => 'Αυτός ο χρήστης δεν ανήκει στο λογαριασμό που δόθηκε.',
    'error_save' => 'Υπήρξε σφάλμα κατά την αποθήκευση των δεδομένων.',
    'error_try_again' => 'Κάτι πήγε στραβά. Παρακαλώ προσπαθήστε ξανά.',
    'error_id' => 'ID Σφάλματος: :id',
    'error_unavailable' => 'Η υπηρεσία δεν είναι διαθέσιμη',
    'error_maintenance' => 'Συντήρηση σε εξέλιξη. Θα επιστρέψουμε σύντομα.',
    'error_help' => 'Θα επιστρέψουμε σύντομα.',
    'error_twitter' => 'Ακολουθήστε <a href="https://twitter.com/:twitter">το λογαριασμό μας στο Twitter</a> για να ενημερωθείτε όταν επανέλθουμε.',
    'error_no_term' => 'Δεν υπάρχει πολιτική για αυτή την εγκατάσταση ακόμη.',

    'default_save_success' => 'Τα δεδομένα αποθηκεύτηκαν.',

    'compliance_title' => 'Με συγχωρείτε για την διακοπή.',
    'compliance_desc' => 'Έχουμε αλλάξει τους <a href=":urlterm" hreflang=":hreflang">Όρους Χρήσης</a> και την <a href=":url" hreflang=":hreflang">Πολιτική Απορρήτου</a>. Σύμφωνα με το νόμο πρέπει να σας ζητήσουμε να ελέγξετε και να αποδεχτείτε για να συνεχίσετε να χρησιμοποιείτε τον λογαριασμό σας.',
    'compliance_desc_end' => 'Δεν κάνουμε τίποτα κακό με τα δεδομένα σας ή το λογαριασμό σας και δεν θα κάνουμε ποτέ.',
    'compliance_terms' => 'Αποδεχτείτε τους νέους όρους και πολιτική απορρήτου',

    // Relationship types
    // Yes, each relationship type has 8 strings associated with it.
    // This is because we need to indicate the name of the relationship type,
    // and also the name of the opposite side of this relationship (father/son),
    // and then, the feminine version of the string. Finally, in some sentences
    // in the UI, we need to include the name of the person we add the relationship
    // to.
    'relationship_type_group_love' => 'Ερωτικές σχέσεις',
    'relationship_type_group_family' => 'Οικογενειακές σχέσεις',
    'relationship_type_group_friend' => 'Φιλικές σχέσεις',
    'relationship_type_group_work' => 'Εργασιακές σχέσεις',
    'relationship_type_group_other' => 'Σχέσεις άλλων τύπων',

    'relationship_type_partner' => 'σύντροφος',
    'relationship_type_partner_female' => 'σύντροφος',
    'relationship_type_partner_male' => 'significant other',
    'relationship_type_partner_with_name' => 'σύντροφος :name',
    'relationship_type_partner_female_with_name' => 'σύντροφος :name',
    'relationship_type_partner_male_with_name' => ':name’s significant other',

    'relationship_type_spouse' => 'σύζυγος',
    'relationship_type_spouse_female' => 'wife',
    'relationship_type_spouse_male' => 'husband',
    'relationship_type_spouse_with_name' => 'σύζυγος :name',
    'relationship_type_spouse_female_with_name' => ':name’s wife',
    'relationship_type_spouse_male_with_name' => ':name’s husband',

    'relationship_type_date' => 'ημερομηνία',
    'relationship_type_date_female' => 'ημερομηνία',
    'relationship_type_date_male' => 'date',
    'relationship_type_date_with_name' => 'ημερομηνία :name',
    'relationship_type_date_female_with_name' => 'ημερομηνία :name',
    'relationship_type_date_male_with_name' => ':name’s date',

    'relationship_type_lover' => 'εραστής',
    'relationship_type_lover_female' => 'εραστής',
    'relationship_type_lover_male' => 'lover',
    'relationship_type_lover_with_name' => 'εραστής :name',
    'relationship_type_lover_female_with_name' => 'εραστής :name',
    'relationship_type_lover_male_with_name' => ':name’s lover',

    'relationship_type_inlovewith' => 'ερωτευμένος με',
    'relationship_type_inlovewith_female' => 'ερωτευμένος με',
    'relationship_type_inlovewith_male' => 'in love with',
    'relationship_type_inlovewith_with_name' => 'κάποιος με τον οποίο ο :name είναι ερωτευμένος',
    'relationship_type_inlovewith_female_with_name' => 'κάποιος με τον οποίο ο :name είναι ερωτευμένος',
    'relationship_type_inlovewith_male_with_name' => 'someone :name is in love with',

    'relationship_type_lovedby' => 'αγαπημένος του',
    'relationship_type_lovedby_female' => 'αγαπημένος του',
    'relationship_type_lovedby_male' => 'loved by',
    'relationship_type_lovedby_with_name' => 'κρυφός εραστής :name',
    'relationship_type_lovedby_female_with_name' => 'κρυφός εραστής της :name',
    'relationship_type_lovedby_male_with_name' => ':name’s secret lover',

    'relationship_type_ex' => 'ex-partner',
    'relationship_type_ex_female' => 'πρώην φίλη',
    'relationship_type_ex_male' => 'ex-boyfriend',
    'relationship_type_ex_with_name' => ':name’s ex-partner',
    'relationship_type_ex_female_with_name' => 'πρώην φίλη :name',
    'relationship_type_ex_male_with_name' => ':name’s ex-boyfriend',

    'relationship_type_parent' => 'parent',
    'relationship_type_parent_female' => 'μητέρα',
    'relationship_type_parent_male' => 'father',
    'relationship_type_parent_with_name' => ':name’s parent',
    'relationship_type_parent_female_with_name' => 'μητέρα :name',
    'relationship_type_parent_male_with_name' => ':name’s father',

    'relationship_type_child' => 'child',
    'relationship_type_child_female' => 'κόρη',
    'relationship_type_child_male' => 'son',
    'relationship_type_child_with_name' => ':name’s child',
    'relationship_type_child_female_with_name' => 'κόρη :name',
    'relationship_type_child_male_with_name' => ':name’s son',

    'relationship_type_stepparent' => 'step-parent',
    'relationship_type_stepparent_female' => 'μητριά',
    'relationship_type_stepparent_male' => 'stepfather',
    'relationship_type_stepparent_with_name' => ':name’s step-parent',
    'relationship_type_stepparent_female_with_name' => 'πατριός :name',
    'relationship_type_stepparent_male_with_name' => ':name’s stepfather',

    'relationship_type_stepchild' => 'stepchild',
    'relationship_type_stepchild_female' => 'κόρη εξ\' αγχιστείας',
    'relationship_type_stepchild_male' => 'stepson',
    'relationship_type_stepchild_with_name' => ':name’s stepchild',
    'relationship_type_stepchild_female_with_name' => 'κόρη εξ\' αγχιστείας του :name',
    'relationship_type_stepchild_male_with_name' => ':name’s stepson',

    'relationship_type_sibling' => 'sibling',
    'relationship_type_sibling_female' => 'αδερφή',
    'relationship_type_sibling_male' => 'brother',
    'relationship_type_sibling_with_name' => ':name’s sibling',
    'relationship_type_sibling_female_with_name' => 'αδερφή του :name',
    'relationship_type_sibling_male_with_name' => ':name’s brother',

    'relationship_type_grandparent' => 'grandparent',
    'relationship_type_grandparent_female' => 'grandmother',
    'relationship_type_grandparent_male' => 'grandfather',
    'relationship_type_grandparent_with_name' => ':name’s grandparent',
    'relationship_type_grandparent_female_with_name' => ':name’s grandmother',
    'relationship_type_grandparent_male_with_name' => ':name’s grandfather',

    'relationship_type_grandchild' => 'grandchild',
    'relationship_type_grandchild_female' => 'granddaughter',
    'relationship_type_grandchild_male' => 'grandson',
    'relationship_type_grandchild_with_name' => ':name’s grandchild',
    'relationship_type_grandchild_female_with_name' => ':name’s granddauther',
    'relationship_type_grandchild_male_with_name' => ':name’s grandson',

    'relationship_type_uncle' => 'θείος',
    'relationship_type_uncle_female' => 'θεία',
    'relationship_type_uncle_male' => 'uncle',
    'relationship_type_uncle_with_name' => 'θείος του :name',
    'relationship_type_uncle_female_with_name' => 'θεία του :name',
    'relationship_type_uncle_male_with_name' => ':name’s uncle',

    'relationship_type_nephew' => 'ανιψιός',
    'relationship_type_nephew_female' => 'ανιψιά',
    'relationship_type_nephew_male' => 'nephew',
    'relationship_type_nephew_with_name' => 'ανιψιός του :name',
    'relationship_type_nephew_female_with_name' => 'ανιψιά του :name',
    'relationship_type_nephew_male_with_name' => ':name’s nephew',

    'relationship_type_cousin' => 'ξάδερφος',
    'relationship_type_cousin_female' => 'ξαδέρφη',
    'relationship_type_cousin_male' => 'cousin',
    'relationship_type_cousin_with_name' => 'ξάδερφος του :name',
    'relationship_type_cousin_female_with_name' => 'ξαδέρφη του :name',
    'relationship_type_cousin_male_with_name' => ':name’s cousin',

    'relationship_type_godfather' => 'godparent',
    'relationship_type_godfather_female' => 'νονά',
    'relationship_type_godfather_male' => 'godfather',
    'relationship_type_godfather_with_name' => ':name’s godparent',
    'relationship_type_godfather_female_with_name' => 'νονά του :name',
    'relationship_type_godfather_male_with_name' => ':name’s godfather',

    'relationship_type_godson' => 'godchild',
    'relationship_type_godson_female' => 'βαφτισιμιά',
    'relationship_type_godson_male' => 'godson',
    'relationship_type_godson_with_name' => ':name’s godchild',
    'relationship_type_godson_female_with_name' => 'βαφτισιμιά του :name',
    'relationship_type_godson_male_with_name' => ':name’s godson',

    'relationship_type_friend' => 'φίλος',
    'relationship_type_friend_female' => 'φίλη',
    'relationship_type_friend_male' => 'friend',
    'relationship_type_friend_with_name' => 'φίλος του :name',
    'relationship_type_friend_female_with_name' => 'φίλη του :name',
    'relationship_type_friend_male_with_name' => ':name’s friend',

    'relationship_type_bestfriend' => 'καλύτερος φίλος',
    'relationship_type_bestfriend_female' => 'καλύτερη φίλη',
    'relationship_type_bestfriend_male' => 'best friend',
    'relationship_type_bestfriend_with_name' => 'καλύτερος φίλος του :name',
    'relationship_type_bestfriend_female_with_name' => 'καλύτερη φίλη του :name',
    'relationship_type_bestfriend_male_with_name' => ':name’s best friend',

    'relationship_type_colleague' => 'συνάδελφος',
    'relationship_type_colleague_female' => 'συνάδελφος',
    'relationship_type_colleague_male' => 'colleague',
    'relationship_type_colleague_with_name' => 'συνάδελφος του :name',
    'relationship_type_colleague_female_with_name' => 'συνάδελφος του :name',
    'relationship_type_colleague_male_with_name' => ':name’s colleague',

    'relationship_type_boss' => 'αφεντικό',
    'relationship_type_boss_female' => 'αφεντικό',
    'relationship_type_boss_male' => 'boss',
    'relationship_type_boss_with_name' => 'αφεντικό του :name',
    'relationship_type_boss_female_with_name' => 'αφεντικό του :name',
    'relationship_type_boss_male_with_name' => ':name’s boss',

    'relationship_type_subordinate' => 'υφιστάμενος',
    'relationship_type_subordinate_female' => 'υφιστάμενη',
    'relationship_type_subordinate_male' => 'subordinate',
    'relationship_type_subordinate_with_name' => 'υφιστάμενος του :name',
    'relationship_type_subordinate_female_with_name' => 'υφιστάμενη του :name',
    'relationship_type_subordinate_male_with_name' => ':name’s subordinate',

    'relationship_type_mentor' => 'σύμβουλος',
    'relationship_type_mentor_female' => 'μέντορας',
    'relationship_type_mentor_male' => 'mentor',
    'relationship_type_mentor_with_name' => 'σύμβουλος του :name',
    'relationship_type_mentor_female_with_name' => 'σύμβουλος της :name',
    'relationship_type_mentor_male_with_name' => ':name’s mentor',

    'relationship_type_protege' => 'protégé',
    'relationship_type_protege_female' => 'protégé',
    'relationship_type_protege_male' => 'protégé',
    'relationship_type_protege_with_name' => ':name’s protégé',
    'relationship_type_protege_female_with_name' => ':name’s protégé',
    'relationship_type_protege_male_with_name' => ':name’s protégé',

    'relationship_type_ex_husband' => 'ex-spouse',
    'relationship_type_ex_husband_female' => 'πρώην σύζυγος',
    'relationship_type_ex_husband_male' => 'ex-husband',
    'relationship_type_ex_husband_with_name' => ':name’s ex-spouse',
    'relationship_type_ex_husband_female_with_name' => 'πρώην σύζυγος της :name',
    'relationship_type_ex_husband_male_with_name' => ':name’s ex-husband',

    // emotions
    'emotion_primary_love' => 'Αγάπη',
    'emotion_primary_joy' => 'Χαρά',
    'emotion_primary_surprise' => 'Έκπληξη',
    'emotion_primary_anger' => 'Θυμός',
    'emotion_primary_sadness' => 'Θλίψη',
    'emotion_primary_fear' => 'Φόβος',

    'emotion_secondary_affection' => 'Στοργή',
    'emotion_secondary_lust' => 'Πόθος',
    'emotion_secondary_longing' => 'Λαχτάρα',
    'emotion_secondary_cheerfulness' => 'Χαρά',
    'emotion_secondary_zest' => 'Ζέση',
    'emotion_secondary_contentment' => 'Ικανοποίηση',
    'emotion_secondary_pride' => 'Περηφάνια',
    'emotion_secondary_optimism' => 'Αισιοδοξία',
    'emotion_secondary_enthrallment' => 'Ενθάρρυνση',
    'emotion_secondary_relief' => 'Ανακούφιση',
    'emotion_secondary_surprise' => 'Έκπληξη',
    'emotion_secondary_irritation' => 'Ενόχληση',
    'emotion_secondary_exasperation' => 'Εξόργιση',
    'emotion_secondary_rage' => 'Θυμός',
    'emotion_secondary_disgust' => 'Αηδία',
    'emotion_secondary_envy' => 'Ζήλια',
    'emotion_secondary_suffering' => 'Ταλαιπωρία',
    'emotion_secondary_sadness' => 'Θλίψη',
    'emotion_secondary_disappointment' => 'Απογοήτευση',
    'emotion_secondary_shame' => 'Ντροπή',
    'emotion_secondary_neglect' => 'Παραμέληση',
    'emotion_secondary_sympathy' => 'Συμπάθεια',
    'emotion_secondary_horror' => 'Τρόμος',
    'emotion_secondary_nervousness' => 'Νευρικότητα',

    'emotion_adoration' => 'Λατρεία',
    'emotion_affection' => 'Στοργή',
    'emotion_love' => 'Αγάπη',
    'emotion_fondness' => 'Συμπάθεια',
    'emotion_liking' => 'Αρέσκεια',
    'emotion_attraction' => 'Έλξη',
    'emotion_caring' => 'Νοιάζομαι',
    'emotion_tenderness' => 'Τρυφερότητα',
    'emotion_compassion' => 'Συμπόνια',
    'emotion_sentimentality' => 'Συναισθηματικότητα',
    'emotion_arousal' => 'Διέγερση',
    'emotion_desire' => 'Επιθυμία',
    'emotion_lust' => 'Πόθος',
    'emotion_passion' => 'Πάθος',
    'emotion_infatuation' => 'Ξελόγιασμα',
    'emotion_longing' => 'Λαχτάρα',
    'emotion_amusement' => 'Ψυχαγωγία',
    'emotion_bliss' => 'Ευδαιμονία',
    'emotion_cheerfulness' => 'Χαρά',
    'emotion_gaiety' => 'Ευθυμία',
    'emotion_glee' => 'Χαρά',
    'emotion_jolliness' => 'Ευχαρίστηση',
    'emotion_joviality' => 'Κέφι',
    'emotion_joy' => 'Χαρά',
    'emotion_delight' => 'Απόλαυση',
    'emotion_enjoyment' => 'Απόλαυση',
    'emotion_gladness' => 'Χαρά',
    'emotion_happiness' => 'Ευτυχία',
    'emotion_jubilation' => 'Αγαλλίαση',
    'emotion_elation' => 'Έξαρση',
    'emotion_satisfaction' => 'Ικανοποίηση',
    'emotion_ecstasy' => 'Έκσταση',
    'emotion_euphoria' => 'Εφορία',
    'emotion_enthusiasm' => 'Ενθουσιασμός',
    'emotion_zeal' => 'Ζήλος',
    'emotion_zest' => 'Ζέση',
    'emotion_excitement' => 'Ενθουσιασμός',
    'emotion_thrill' => 'Συγκίνηση',
    'emotion_exhilaration' => 'Χαρά',
    'emotion_contentment' => 'Ικανοποίηση',
    'emotion_pleasure' => 'Απόλαυση',
    'emotion_pride' => 'Περηφάνια',
    'emotion_eagerness' => 'Προθυμία',
    'emotion_hope' => 'Ελπίδα',
    'emotion_optimism' => 'Αισιοδοξία',
    'emotion_enthrallment' => 'Ενθάρρυνση',
    'emotion_rapture' => 'Αγαλλίαση',
    'emotion_relief' => 'Ανακούφιση',
    'emotion_amazement' => 'Κατάπληξη',
    'emotion_surprise' => 'Έκπληξη',
    'emotion_astonishment' => 'Έκπληκτος',
    'emotion_aggravation' => 'Επιδείνωση',
    'emotion_irritation' => 'Ερεθισμός',
    'emotion_agitation' => 'Ταραχή',
    'emotion_annoyance' => 'Ενόχληση',
    'emotion_grouchiness' => 'Δυστροπία',
    'emotion_grumpiness' => 'Γκρίνια',
    'emotion_exasperation' => 'Εξόργιση',
    'emotion_frustration' => 'Εκνευρισμός',
    'emotion_anger' => 'Θυμός',
    'emotion_rage' => 'Οργή',
    'emotion_outrage' => 'Προσβολή',
    'emotion_fury' => 'Θυμός',
    'emotion_wrath' => 'Οργή',
    'emotion_hostility' => 'Εχθρότητα',
    'emotion_ferocity' => 'Αγριότητα',
    'emotion_bitterness' => 'Πικρία',
    'emotion_hate' => 'Μίσος',
    'emotion_loathing' => 'Σιχαμάρα',
    'emotion_scorn' => 'Περιφρόνηση',
    'emotion_spite' => 'Πείσμα',
    'emotion_vengefulness' => 'Εκδικητικότητα',
    'emotion_dislike' => 'Αντιπάθεια',
    'emotion_resentment' => 'Μνησικακία',
    'emotion_disgust' => 'Αηδία',
    'emotion_revulsion' => 'Μεταστροφή',
    'emotion_contempt' => 'Περιφρόνηση',
    'emotion_envy' => 'Φθόνος',
    'emotion_jealousy' => 'Ζήλια',
    'emotion_agony' => 'Αγωνία',
    'emotion_suffering' => 'Ταλαιπωρία',
    'emotion_hurt' => 'Πόνος',
    'emotion_anguish' => 'Οδύνη',
    'emotion_depression' => 'Κατάθλιψη',
    'emotion_despair' => 'Απόγνωση',
    'emotion_hopelessness' => 'Απελπισία',
    'emotion_gloom' => 'Κατηφής',
    'emotion_glumness' => 'Κατήφεια',
    'emotion_sadness' => 'Θλίψη',
    'emotion_unhappiness' => 'Δυστυχία',
    'emotion_grief' => 'Πένθος',
    'emotion_sorrow' => 'Πόνος',
    'emotion_woe' => 'Συμφορά',
    'emotion_misery' => 'Μιζέρια',
    'emotion_melancholy' => 'Μελαγχολία',
    'emotion_dismay' => 'Φόβος',
    'emotion_disappointment' => 'Απογοήτευση',
    'emotion_displeasure' => 'Δυσαρέσκεια',
    'emotion_guilt' => 'Ενοχή',
    'emotion_shame' => 'Ντροπή',
    'emotion_regret' => 'Μετάνοια',
    'emotion_remorse' => 'Τύψεις',
    'emotion_alienation' => 'Αποξένωση',
    'emotion_isolation' => 'Απομόνωση',
    'emotion_neglect' => 'Παραμέληση',
    'emotion_loneliness' => 'Μοναξιά',
    'emotion_rejection' => 'Απόρριψη',
    'emotion_homesickness' => 'Νοσταλγία',
    'emotion_defeat' => 'Ήττα',
    'emotion_dejection' => 'Κατήφεια',
    'emotion_insecurity' => 'Ανασφάλεια',
    'emotion_embarrassment' => 'Ντροπή',
    'emotion_humiliation' => 'Ταπείνωση',
    'emotion_insult' => 'Προσβολή',
    'emotion_pity' => 'Οίκτος',
    'emotion_sympathy' => 'Συμπάθεια',
    'emotion_alarm' => 'Ανήσυχος',
    'emotion_shock' => 'Έκπληξη',
    'emotion_fear' => 'Φόβος',
    'emotion_fright' => 'Τρομάρα',
    'emotion_horror' => 'Τρόμος',
    'emotion_terror' => 'Τρόμος',
    'emotion_panic' => 'Πανικός',
    'emotion_hysteria' => 'Υστερία',
    'emotion_mortification' => 'Ταπείνωση',
    'emotion_anxiety' => 'Ανησυχία',
    'emotion_nervousness' => 'Νευρικότητα',
    'emotion_tenseness' => 'Υπερένταση',
    'emotion_uneasiness' => 'Ανησυχία',
    'emotion_apprehension' => 'Σύλληψη',
    'emotion_worry' => 'Ανησυχία',
    'emotion_distress' => 'Δυσφορία',
    'emotion_dread' => 'Τρόμος',

    // weather
    'weather_sunny' => 'Λιακάδα',
    'weather_clear' => 'Καθαρός',
    'weather_clear-day' => 'Καθαρός',
    'weather_clear-night' => 'Καθαρή νύχτα',
    'weather_light-drizzle' => 'Ψιλόβροχο',
    'weather_patchy-light-drizzle' => 'Σποραδικό ψιλόβροχο',
    'weather_patchy-light-rain' => 'Σποραδική ελαφριά βροχή',
    'weather_light-rain' => 'Ελαφρά βροχόπτωση',
    'weather_moderate-rain-at-times' => 'Μέτρια βροχή κατά καιρούς',
    'weather_moderate-rain' => 'Μέτρια βροχή',
    'weather_patchy-rain-possible' => 'Πιθανή σποραδική βροχή',
    'weather_heavy-rain-at-times' => 'Βαριά βροχή κατά καιρούς',
    'weather_heavy-rain' => 'Έντονη βροχή',
    'weather_light-freezing-rain' => 'Ελαφριά παγωμένη βροχή',
    'weather_moderate-or-heavy-freezing-rain' => 'Μέτρια ή δυνατή παγωμένη βροχή',
    'weather_light-sleet' => 'Ελαφρύ χιονόνερο',
    'weather_moderate-or-heavy-rain-shower' => 'Μέτρια ή δυνατή βροχή',
    'weather_light-rain-shower' => 'Ελαφριά βροχή',
    'weather_torrential-rain-shower' => 'Καταρρακτώδης βροχή',
    'weather_rain' => 'Βροχή',
    'weather_snow' => 'Χιόνι',
    'weather_blowing-snow' => 'Χιονόπτωση με αέρα',
    'weather_patchy-light-snow' => 'Αραιό χιόνι',
    'weather_light-snow' => 'Ελαφρά χιονόπτωση',
    'weather_patchy-moderate-snow' => 'Patchy moderate snow',
    'weather_moderate-snow' => 'Μέτρια χιονόπτωση',
    'weather_patchy-heavy-snow' => 'Patchy heavy snow',
    'weather_heavy-snow' => 'Ισχυρή χιονόπτωση',
    'weather_light-snow-showers' => 'Light snow showers',
    'weather_moderate-or-heavy-snow-showers' => 'Moderate or heavy snow showers',
    'weather_patchy-snow-possible' => 'Patchy snow possible',
    'weather_patchy-sleet-possible' => 'Patchy sleet possible',
    'weather_moderate-or-heavy-sleet' => 'Moderate or heavy sleet',
    'weather_light-sleet-showers' => 'Light sleet showers',
    'weather_moderate-or-heavy-sleet-showers' => 'Moderate or heavy sleet showers',
    'weather_sleet' => 'Χιονόνερο',
    'weather_wind' => 'Άνεμος',
    'weather_fog' => 'Ομίχλη',
    'weather_freezing-fog' => 'Παγωμένη ομίχλη',
    'weather_mist' => 'Ομίχλη',
    'weather_blizzard' => 'Χιονοθύελλα',
    'weather_overcast' => 'Νεφελώδης',
    'weather_cloudy' => 'Συννεφιά',
    'weather_partly-cloudy-day' => 'Αραιές νεφώσεις',
    'weather_partly-cloudy-night' => 'Αραιές νεφώσεις',
    'weather_freezing-drizzle' => 'Παγωμένο ψιλόβροχο',
    'weather_heavy-freezing-drizzle' => 'Heavy freezing drizzle',
    'weather_patchy-freezing-drizzle-possible' => 'Patchy freezing drizzle possible',
    'weather_ice-pellets' => 'Ice pellets',
    'weather_light-showers-of-ice-pellets' => 'Light showers of ice pellets',
    'weather_moderate-or-heavy-showers-of-ice-pellets' => 'Moderate or heavy showers of ice pellets',
    'weather_thundery-outbreaks-possible' => 'Thundery outbreaks possible',
    'weather_patchy-light-rain-with-thunder' => 'Patchy light rain with thunder',
    'weather_moderate-or-heavy-rain-with-thunder' => 'Moderate or heavy rain with thunder',
    'weather_patchy-light-snow-with-thunder' => 'Patchy light snow with thunder',
    'weather_moderate-or-heavy-snow-with-thunder' => 'Moderate or heavy snow with thunder',
    'weather_current_temperature_celsius' => ':temperature °C',
    'weather_current_temperature_fahrenheit' => ':temperature °F',
    'weather_current_title' => 'Τρέχων καιρός',

    // dav
    'dav_contacts' => 'Επαφές',
    'dav_contacts_description' => 'Επαφές του :name',
    'dav_birthdays' => 'Γενέθλια',
    'dav_birthdays_description' => 'Γενέθλια επαφών του :name',
    'dav_tasks' => 'Εργασίες',
    'dav_tasks_description' => 'εργασίες του :name',

    // contact list
    'contact_list_avatar' => 'Avatar',
    'contact_list_name' => 'Επαφή',
    'contact_list_description' => 'Περιγραφή',

];
